==> risk-center-api-0.4.0-20180725.035223-3-sources.jar: cn/com/duiba/tuia/risk/center/api/dto/RpsEngineFieldDto.java <==
package cn.com.duiba.tuia.risk.center.api.dto;

import java.io.Serializable;
import java.util.Date;
import java.util.List;

import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;

/**
 * 字段管理
 */
@ApiModel
public class RpsEngineFieldDto implements Serializable {

    private static final long serialVersionUID = 1L;

    /**
    * 
    */
    private Integer           id;

    /**
     * 字段名称
     */
    @ApiModelProperty("字段名称")
    private String            name;

    /**
     * 字段类型:  '0' 数值  '1' 字符串
     */
    @ApiModelProperty("字段类型:  '0' 数值  '1' 字符串")
    private String            type;

    /**
     * 表名称
     */
    @ApiModelProperty("表名称")
    private String            tableName;

    /**
     * 表字段
     */
    @ApiModelProperty("表字段")
    private String            tableColumn;

    /**
     * 所属场景
     */
    @ApiModelProperty("所属场景")
    private Long              sceneId;

    /**
     * 前端显示所属场景名称列表
     */
    private List<EngineFieldDto> sceneNames;

    /**
     * 创建者
     */
    private String            creator;

    /**
     * 修改者
     */
    private String            editor;

    /**
     * 创建时间
     */
    private Date              gmtCreate;

    /**
     * 修改时间
     */
    private Date              gmtModified;

    /**
     * 页面显示修改时间
     */
    private String            gmtModifiedView;

    public Integer getId() {
        return id;
    }

    public void setId(Integer id) {
        this.id = id;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public String getType() {
        return type;
    }

    public void setType(String type) {
        this.type = type;
    }

    public String getTableName() {
        return tableName;
    }

    public void setTableName(String tableName) {
        this.tableName = tableName;
    }

    public String getTableColumn() {
        return tableColumn;
    }

    public void setTableColumn(String tableColumn) {
        this.tableColumn = tableColumn;
    }

    public Long getSceneId() {
        return sceneId;
    }

    public void setSceneId(Long sceneId) {
        this.sceneId = sceneId;
    }

    public List<EngineFieldDto> getSceneNames() {
        return sceneNames;
    }

    public void setSceneNames(List<EngineFieldDto> sceneNames) {
        this.sceneNames = sceneNames;
    }

    public String getCreator() {
        return creator;
    }

    public void setCreator(String creator) {
        this.creator = creator;
    }

    public String getEditor() {
        return editor;
    }

    public void setEditor(String editor) {
        this.editor = editor;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }

    public String getGmtModifiedView() {
        return gmtModifiedView;
    }

    public void setGmtModifiedView(String gmtModifiedView) {
        this.gmtModifiedView = gmtModifiedView;
    }
}

==> risk-center-api-0.4.17-sources.jar: cn/com/duiba/tuia/risk/center/api/dto/RpsEngineFieldDto.java <==
package cn.com.duiba.tuia.risk.center.api.dto;

import java.io.Serializable;
import java.util.Date;
import java.util.List;

import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;

/**
 * 字段管理
 */
@ApiModel
public class RpsEngineFieldDto implements Serializable {

    private static final long serialVersionUID = 1L;

    /**
    * 
    */
    private Integer           id;

    /**
     * 字段名称
     */
    @ApiModelProperty("字段名称")
    private String            name;

    /**
     * 字段类型:  '0' 数值  '1' 字符串
     */
    @ApiModelProperty("字段类型:  '0' 数值  '1' 字符串")
    private String            type;

    /**
     * 描述
     */
    private String            description;

    /**
     * 表名称
     */
    @ApiModelProperty("表名称")
    private String            tableName;

    /**
     * 表字段
     */
    @ApiModelProperty("表字段")
    private String            tableColumn;

    /**
     * 所属场景
     */
    @ApiModelProperty("所属场景")
    private Long              sceneId;

    /**
     * 前端显示所属场景名称列表
     */
    private List<EngineFieldDto> sceneNames;

    /**
     * 创建者
     */
    private String            creator;

    /**
     * 修改者
     */
    private String            editor;

    /**
     * 创建时间
     */
    private Date              gmtCreate;

    /**
     * 修改时间
     */
    private Date              gmtModified;

    /**
     * 页面显示修改时间
     */
    private String            gmtModifiedView;

    public Integer getId() {
        return id;
    }

    public void setId(Integer id) {
        this.id = id;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public String getType() {
        return type;
    }

    public void setType(String type) {
        this.type = type;
    }

    public String getTableName() {
        return tableName;
    }

    public void setTableName(String tableName) {
        this.tableName = tableName;
    }

    public String getTableColumn() {
        return tableColumn;
    }

    public void setTableColumn(String tableColumn) {
        this.tableColumn = tableColumn;
    }

    public Long getSceneId() {
        return sceneId;
    }

    public void setSceneId(Long sceneId) {
        this.sceneId = sceneId;
    }

    public List<EngineFieldDto> getSceneNames() {
        return sceneNames;
    }

    public void setSceneNames(List<EngineFieldDto> sceneNames) {
        this.sceneNames = sceneNames;
    }

    public String getCreator() {
        return creator;
    }

    public void setCreator(String creator) {
        this.creator = creator;
    }

    public String getEditor() {
        return editor;
    }

    public void setEditor(String editor) {
        this.editor = editor;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }

    public String getGmtModifiedView() {
        return gmtModifiedView;
    }

    public void setGmtModifiedView(String gmtModifiedView) {
        this.gmtModifiedView = gmtModifiedView;
    }

    public String getDescription() {
        return description;
    }

    public void setDescription(String description) {
        this.description = description;
    }
}
